@@ -31,6 +31,7 @@
 #include "util.h"
 #include "mpi.h"
 #include "cipher.h"
+#include "i18n.h"
 
 static int no_of_small_prime_numbers;
 static MPI gen_prime( unsigned	nbits, int mode, int randomlevel );
@@ -304,6 +305,12 @@ gen_prime( unsigned  nbits, int secret, int randomlevel )
     if( 0 && DBG_CIPHER )
 	log_debug("generate a prime of %u bits ", nbits );
 
+    if (nbits < 16)
+      {
+        log_error (_("can't generate a prime with less than %d bits\n"), 16);
+        exit (2);
+      }
+
     if( !no_of_small_prime_numbers ) {
 	for(i=0; small_prime_numbers[i]; i++ )
 	    no_of_small_prime_numbers++;
@@ -490,6 +497,7 @@ is_prime( MPI n, int steps, int *count )
     mpi_free( z );
     mpi_free( nminus1 );
     mpi_free( q );
+    mpi_free (a2);
 
     return rc;
 }
